@@ -11,9 +11,10 @@
 
 package Config::Model::TkUI ;
 {
-  $Config::Model::TkUI::VERSION = '1.333';
+  $Config::Model::TkUI::VERSION = '1.334';
 }
 
+use 5.10.1 ;
 use strict;
 use warnings ;
 use Carp ;
@@ -119,7 +120,7 @@ sub Populate {
     my $extra_menu = delete $args->{'-extra-menu'} || [] ;
 
     my $title = delete $args->{'-title'}
-              || "config-edit ".$cw->{root}->config_class_name ;
+              || $0." ".$cw->{root}->config_class_name ;
 
     # check unknown parameters
     croak "Unknown parameter ",join(' ',keys %$args) if %$args;
@@ -139,6 +140,7 @@ sub Populate {
 		      [ qw/command reload -command/, sub{ $cw->reload }],
 		      [ command => 'check for errors',    -command => sub{ $cw->check(1)} ],
 		      [ command => 'check for warnings',  -command => sub{ $cw->check(1,1)} ],
+		      [ command => 'show changes',  -command => sub{ $cw->show_changes;} ],
 		      [ qw/command save   -command/, sub{ $cw->save }],
 		      [ command => 'save in dir ...',
                         -command => sub{ $cw->save_in_dir ;} ],
@@ -423,20 +425,28 @@ sub save_if_yes {
     my $cw =shift ;
     my $text = shift || "Save data ?" ;
 
+    my $ok_to_quit ;
     if ($cw->{root}->instance->needs_save) {
 	my $answer = $cw->Dialog(-title => "quit",
 				 -text  => $text,
-				 -buttons => [ qw/yes no/],
+				 -buttons => [ qw/yes no cancel/, 'show changes'],
 				 -default_button => 'yes',
 				)->Show ;
-	$cw->save if $answer eq 'yes';
+	given ($answer) {
+            when ('yes') { $cw->save; $ok_to_quit = 1 ;}
+            when ('no')  {            $ok_to_quit = 1 ;}
+            when ('cancel')  {            $ok_to_quit = 0 ;}
+            when (/show/)  { $cw->show_changes(sub{$cw -> save_if_yes}) ;  $ok_to_quit = 0 ;}
+	}
     }
+
+    return $ok_to_quit ;
 }
 
 sub quit {
     my $cw = shift ;
 
-    $cw->save_if_yes ;
+    $cw->save_if_yes || return ;
 
     if (defined $cw->{quit} and $cw->{quit} eq 'soft') {
 	$cw->destroy ;
@@ -447,6 +457,19 @@ sub quit {
     }
 }
 
+sub show_changes {
+    my $cw = shift ;
+    my $cb = shift ;
+    
+    my $changes = $cw->{root}->instance->list_changes ;
+    my $change_widget = $cw->Toplevel ;
+    $change_widget->Scrolled('ROText')->pack ->insert('1.0',$changes);
+    $change_widget->Button(
+        -command => sub {$change_widget->destroy; $cb ->() if defined $cb;} ,
+        -text => 'ok',
+    )->pack ;
+}
+
 sub reload {
     my $cw =shift ;
     carp "reload: too many parameters" if @_ > 1 ;
